import { NonNullablePaths } from '@wix/sdk-types';

interface ReferralProgram {
    /**
     * Referral program name.
     * @minLength 2
     * @maxLength 50
     */
    name?: string | null;
    /** @readonly */
    status?: ProgramStatusWithLiterals;
    /**
     * Revision number, which increments by 1 each time the program is updated.
     * To prevent conflicting changes, the current `revision` must be passed when updating the program.
     * @immutable
     */
    revision?: string | null;
    /**
     * Date and time the program was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the program was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Reward configuration for the referred friend.
     * Specifies the reward given to a new customer who was referred to the business.
     */
    referredFriendReward?: Reward;
    /**
     * Reward configuration for the referring customer.
     * Specifies the reward given to an existing customer who referred a new customer to the business.
     */
    referringCustomerReward?: Reward;
    /**
     * List of actions that complete a referral. For an action to be considered successful, the referred friend must place and pay for an item.
     * @maxSize 100
     */
    successfulReferralActions?: ActionWithLiterals[];
    /** Configures email notifications for the referral program. */
    emails?: Emails;
    /**
     * Indicates which premium features are available for the current account.
     * @readonly
     */
    premiumFeatures?: PremiumFeatures;
}
/** Status of the referral program. */
declare enum ProgramStatus {
    /** Unknown program status. */
    UNKNOWN = "UNKNOWN",
    /** Referral program is in a draft state and is being modified. It is not yet active. */
    DRAFT = "DRAFT",
    /** Referral program is active. */
    ACTIVE = "ACTIVE",
    /** Referral program is paused. */
    PAUSED = "PAUSED"
}
/** @enumType */
type ProgramStatusWithLiterals = ProgramStatus | 'UNKNOWN' | 'DRAFT' | 'ACTIVE' | 'PAUSED';
interface Reward extends RewardOptionsOneOf {
    /** Options for coupon reward type. */
    couponOptions?: Coupon;
    /** Options for the Loyalty points reward type. */
    loyaltyPointsOptions?: LoyaltyPoints;
    /** Type of the reward. */
    type?: TypeWithLiterals;
}
/** @oneof */
interface RewardOptionsOneOf {
    /** Options for coupon reward type. */
    couponOptions?: Coupon;
    /** Options for the Loyalty points reward type. */
    loyaltyPointsOptions?: LoyaltyPoints;
}
declare enum Type {
    /** Unknown reward type. */
    UNKNOWN = "UNKNOWN",
    /** Coupon reward type. */
    COUPON = "COUPON",
    /** Loyalty points reward type. */
    LOYALTY_POINTS = "LOYALTY_POINTS",
    /** No reward type. */
    NOTHING = "NOTHING"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN' | 'COUPON' | 'LOYALTY_POINTS' | 'NOTHING';
interface Coupon extends CouponDiscountTypeOptionsOneOf, CouponScopeOrMinSubtotalOneOf {
    /** Options for fixed amount discount. */
    fixedAmountOptions?: FixedAmountDiscount;
    /** Options for percentage discounts. */
    percentageOptions?: PercentageDiscount;
    /** Limit the coupon to carts with a subtotal above this number. */
    minimumSubtotal?: number;
    /** Specifies the type of line items this coupon will apply to. See [valid scope values](https://dev.wix.com/api/rest/coupons/coupons/valid-scope-values). */
    scope?: CouponScope;
    /**
     * Coupon name.
     * @minLength 1
     * @maxLength 50
     */
    name?: string;
    /** Coupon discount type. */
    discountType?: DiscountTypeWithLiterals;
    /**
     * Whether the coupon is limited to one item.
     * If `true` and a customer pays for multiple items, the discount applies to only the lowest priced item.
     * Coupons with a bookings `scope.namespace` are always limited to one item.
     */
    limitedToOneItem?: boolean | null;
    /** Whether the coupon applies to subscription products. */
    appliesToSubscriptions?: boolean | null;
    /**
     * Specifies the amount of discounted cycles for a subscription item.
     *
     * - Can only be set when `scope.namespace = pricingPlans`.
     * - If `discountedCycleCount` is empty, the coupon applies to all available cycles.
     * - `discountedCycleCount` is ignored if `appliesToSubscriptions = true`.
     *
     * Max: `999`
     */
    discountedCycleCount?: number | null;
}
/** @oneof */
interface CouponDiscountTypeOptionsOneOf {
    /** Options for fixed amount discount. */
    fixedAmountOptions?: FixedAmountDiscount;
    /** Options for percentage discounts. */
    percentageOptions?: PercentageDiscount;
}
/** @oneof */
interface CouponScopeOrMinSubtotalOneOf {
    /** Limit the coupon to carts with a subtotal above this number. */
    minimumSubtotal?: number;
    /** Specifies the type of line items this coupon will apply to. See [valid scope values](https://dev.wix.com/api/rest/coupons/coupons/valid-scope-values). */
    scope?: CouponScope;
}
declare enum DiscountType {
    /** Unknown discount type. */
    UNKNOWN = "UNKNOWN",
    /** Discount as a fixed amount. */
    FIXED_AMOUNT = "FIXED_AMOUNT",
    /** Discount as a percentage. */
    PERCENTAGE = "PERCENTAGE",
    /** Free shipping. If `true`, the coupon applies to all items in all `namespaces`. */
    FREE_SHIPPING = "FREE_SHIPPING"
}
/** @enumType */
type DiscountTypeWithLiterals = DiscountType | 'UNKNOWN' | 'FIXED_AMOUNT' | 'PERCENTAGE' | 'FREE_SHIPPING';
interface FixedAmountDiscount {
    /** Amount of the discount as a fixed value. */
    amount?: number;
}
interface PercentageDiscount {
    /**
     * Percentage of discount.
     * @max 100
     */
    percentage?: number;
}
interface CouponScope {
    /** Scope namespace (Wix Stores, Wix Bookings, Wix Events, Wix Pricing Plans) */
    namespace?: string;
    /** Coupon scope's applied group, for example, Event or ticket in Wix Events. */
    group?: Group;
}
interface Group {
    /** Name of the group. */
    name?: string;
    /** Entity ID of the group. */
    entityId?: string | null;
}
interface LoyaltyPoints {
    /**
     * Number of loyalty points to give.
     * @min 1
     * @max 9999999
     */
    amount?: number;
}
declare enum Action {
    /** Unknown action. */
    UNKNOWN = "UNKNOWN",
    /** Referred friend ordered and paid for an order in a store. */
    STORE_ORDER_PLACED = "STORE_ORDER_PLACED",
    /** Referred friend ordered and paid for a plan. */
    PLAN_ORDERED = "PLAN_ORDERED",
    /** Referred friend ordered and paid for a ticket. */
    TICKET_ORDERED = "TICKET_ORDERED",
    /** Referred friend booked and paid for a session. */
    SESSION_BOOKED = "SESSION_BOOKED",
    /** Referred friend placed and paid for a restaurant order. */
    RESTAURANT_ORDER_PLACED = "RESTAURANT_ORDER_PLACED",
    /** Referred friend joined an online program. */
    ONLINE_PROGRAM_JOINED = "ONLINE_PROGRAM_JOINED"
}
/** @enumType */
type ActionWithLiterals = Action | 'UNKNOWN' | 'STORE_ORDER_PLACED' | 'PLAN_ORDERED' | 'TICKET_ORDERED' | 'SESSION_BOOKED' | 'RESTAURANT_ORDER_PLACED' | 'ONLINE_PROGRAM_JOINED';
interface Emails {
    /** Configures email invitations to encourage customers to refer their friends. Select the apps for which this feature is enabled. */
    encourageToReferFriends?: AppWithLiterals[];
    /**
     * Whether to send email notifications to referring customers when they receive a referral reward.
     * If true, referring customers will be notified by email when their referred friend completes a qualifying action (for example, placing an order).
     */
    notifyCustomersAboutReward?: boolean;
}
declare enum App {
    /** Unknown app. */
    UNKNOWN = "UNKNOWN",
    /** Send an email to customers who've placed an order with stores. */
    STORES = "STORES",
    /** Send an email to customers who've placed an order with pricing plans. */
    PRICING_PLANS = "PRICING_PLANS",
    /** Send an email to customers who've placed an order with events. */
    EVENTS = "EVENTS",
    /** Send an email to customers who've placed an order with bookings. */
    BOOKINGS = "BOOKINGS",
    /** Send an email to customers who've placed an order with restaurants. */
    RESTAURANTS = "RESTAURANTS",
    /** Send an email to customers who've joined an online program. */
    ONLINE_PROGRAMS = "ONLINE_PROGRAMS"
}
/** @enumType */
type AppWithLiterals = App | 'UNKNOWN' | 'STORES' | 'PRICING_PLANS' | 'EVENTS' | 'BOOKINGS' | 'RESTAURANTS' | 'ONLINE_PROGRAMS';
interface PremiumFeatures {
    /**
     * Whether the site owner has access to the referral program feature.
     * @readonly
     */
    referralProgram?: boolean;
}
interface GetReferralProgramRequest {
}
interface GetReferralProgramResponse {
    /** Retrieved referral program. */
    referralProgram?: ReferralProgram;
}
interface BulkGetReferralProgramRequest {
}
interface BulkGetReferralProgramResponse {
    /** Retrieved referral programs. */
    programInSites?: ProgramInSite[];
}
interface ProgramInSite {
    /**
     * Metasite ID.
     * @format GUID
     */
    metaSiteId?: string;
    /** Retrieved referral program. */
    referralProgram?: ReferralProgram;
}
interface UpdateReferralProgramRequest {
    /** Referral program to update. Include the latest `revision` for a successful update. */
    referralProgram: ReferralProgram;
}
interface UpdateReferralProgramResponse {
    /** Updated referral program. */
    referralProgram?: ReferralProgram;
}
interface ActivateReferralProgramRequest {
}
interface ActivateReferralProgramResponse {
    /** Activated referral program. */
    referralProgram?: ReferralProgram;
}
interface PauseReferralProgramRequest {
}
interface PauseReferralProgramResponse {
    /** Paused referral program. */
    referralProgram?: ReferralProgram;
}
interface GetAISocialMediaPostsSuggestionsRequest {
    /**
     * Topic to generate social media post suggestions for. For example, fitness, education, or technology.
     * @maxLength 512
     */
    topic?: string;
}
interface GetAISocialMediaPostsSuggestionsResponse {
    /**
     * Generated social media post suggestions.
     * @maxSize 3
     */
    suggestions?: AISocialMediaPostSuggestion[];
    /**
     * Referral URL to refer friends.
     * @maxLength 2083
     */
    referFriendsPageUrl?: string | null;
}
interface AISocialMediaPostSuggestion {
    /**
     * Suggested post content.
     * @maxLength 4096
     */
    postContent?: string;
    /**
     * Suggested hashtags.
     * @maxLength 256
     * @maxSize 256
     */
    hashtags?: string[];
}
interface GenerateAISocialMediaPostsSuggestionsRequest {
    /**
     * Topic to generate social media post suggestions for. For example, fitness, education, or technology.
     * @maxLength 512
     */
    topic?: string;
}
interface GenerateAISocialMediaPostsSuggestionsResponse {
    /**
     * Generated social media post suggestions.
     * @maxSize 3
     */
    suggestions?: AISocialMediaPostSuggestion[];
    /**
     * Referral URL to refer friends.
     * @maxLength 2083
     */
    referFriendsPageUrl?: string | null;
}
interface GetReferralProgramPremiumFeaturesRequest {
}
interface GetReferralProgramPremiumFeaturesResponse {
    /**
     * Whether the site has the referral program feature enabled.
     * @readonly
     */
    referralProgram?: boolean;
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface Empty {
}
interface MetaSiteSpecialEvent extends MetaSiteSpecialEventPayloadOneOf {
    /** Emitted on a meta site creation. */
    siteCreated?: SiteCreated;
    /** Emitted on a meta site transfer completion. */
    siteTransferred?: SiteTransferred;
    /** Emitted on a meta site deletion. */
    siteDeleted?: SiteDeleted;
    /** Emitted on a meta site restoration. */
    siteUndeleted?: SiteUndeleted;
    /** Emitted on the first* publish of the meta site (* switching from unpublished to published state). */
    sitePublished?: SitePublished;
    /** Emitted on a meta site unpublish. */
    siteUnpublished?: SiteUnpublished;
    /** Emitted when meta site is marked as template. */
    siteMarkedAsTemplate?: SiteMarkedAsTemplate;
    /** Emitted when meta site is marked as a WixSite. */
    siteMarkedAsWixSite?: SiteMarkedAsWixSite;
    /** Emitted when an application is provisioned (installed). */
    serviceProvisioned?: ServiceProvisioned;
    /** Emitted when an application is removed (uninstalled). */
    serviceRemoved?: ServiceRemoved;
    /** Emitted when meta site name (URL slug) is changed. */
    siteRenamedPayload?: SiteRenamed;
    /** Emitted when meta site was permanently deleted. */
    hardDeleted?: SiteHardDeleted;
    /** Emitted on a namespace change. */
    namespaceChanged?: NamespaceChanged;
    /** Emitted when Studio is attached. */
    studioAssigned?: StudioAssigned;
    /** Emitted when Studio is detached. */
    studioUnassigned?: StudioUnassigned;
    /**
     * Emitted when one of the URLs is changed. After this event you may call `urls-server` to fetch
     * the actual URL.
     *
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1732520791210559?thread_ts=1732027914.294059&cid=C0UHEBPFT
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1744115197619459
     */
    urlChanged?: SiteUrlChanged;
    /** Site is marked as PurgedExternally */
    sitePurgedExternally?: SitePurgedExternally;
    /** Emitted when Odeditor is attached. */
    odeditorAssigned?: OdeditorAssigned;
    /** Emitted when Odeditor is detached. */
    odeditorUnassigned?: OdeditorUnassigned;
    /** Emitted when Picasso is attached. */
    picassoAssigned?: PicassoAssigned;
    /** Emitted when Picasso is detached. */
    picassoUnassigned?: PicassoUnassigned;
    /**
     * A meta site id.
     * @format GUID
     */
    metaSiteId?: string;
    /** A meta site version. Monotonically increasing. */
    version?: string;
    /** A timestamp of the event. */
    timestamp?: string;
    /**
     * TODO(meta-site): Change validation once validations are disabled for consumers
     * More context: https://wix.slack.com/archives/C0UHEBPFT/p1720957844413149 and https://wix.slack.com/archives/CFWKX325T/p1728892152855659
     * @maxSize 4000
     */
    assets?: Asset[];
}
/** @oneof */
interface MetaSiteSpecialEventPayloadOneOf {
    /** Emitted on a meta site creation. */
    siteCreated?: SiteCreated;
    /** Emitted on a meta site transfer completion. */
    siteTransferred?: SiteTransferred;
    /** Emitted on a meta site deletion. */
    siteDeleted?: SiteDeleted;
    /** Emitted on a meta site restoration. */
    siteUndeleted?: SiteUndeleted;
    /** Emitted on the first* publish of the meta site (* switching from unpublished to published state). */
    sitePublished?: SitePublished;
    /** Emitted on a meta site unpublish. */
    siteUnpublished?: SiteUnpublished;
    /** Emitted when meta site is marked as template. */
    siteMarkedAsTemplate?: SiteMarkedAsTemplate;
    /** Emitted when meta site is marked as a WixSite. */
    siteMarkedAsWixSite?: SiteMarkedAsWixSite;
    /** Emitted when an application is provisioned (installed). */
    serviceProvisioned?: ServiceProvisioned;
    /** Emitted when an application is removed (uninstalled). */
    serviceRemoved?: ServiceRemoved;
    /** Emitted when meta site name (URL slug) is changed. */
    siteRenamedPayload?: SiteRenamed;
    /** Emitted when meta site was permanently deleted. */
    hardDeleted?: SiteHardDeleted;
    /** Emitted on a namespace change. */
    namespaceChanged?: NamespaceChanged;
    /** Emitted when Studio is attached. */
    studioAssigned?: StudioAssigned;
    /** Emitted when Studio is detached. */
    studioUnassigned?: StudioUnassigned;
    /**
     * Emitted when one of the URLs is changed. After this event you may call `urls-server` to fetch
     * the actual URL.
     *
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1732520791210559?thread_ts=1732027914.294059&cid=C0UHEBPFT
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1744115197619459
     */
    urlChanged?: SiteUrlChanged;
    /** Site is marked as PurgedExternally */
    sitePurgedExternally?: SitePurgedExternally;
    /** Emitted when Odeditor is attached. */
    odeditorAssigned?: OdeditorAssigned;
    /** Emitted when Odeditor is detached. */
    odeditorUnassigned?: OdeditorUnassigned;
    /** Emitted when Picasso is attached. */
    picassoAssigned?: PicassoAssigned;
    /** Emitted when Picasso is detached. */
    picassoUnassigned?: PicassoUnassigned;
}
interface Asset {
    /**
     * An application definition id (app_id in dev-center). For legacy reasons may be UUID or a string (from Java Enum).
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * An instance id. For legacy reasons may be UUID or a string.
     * @maxLength 200
     */
    instanceId?: string;
    /** An application state. */
    state?: StateWithLiterals;
}
declare enum State {
    UNKNOWN = "UNKNOWN",
    ENABLED = "ENABLED",
    DISABLED = "DISABLED",
    PENDING = "PENDING",
    DEMO = "DEMO"
}
/** @enumType */
type StateWithLiterals = State | 'UNKNOWN' | 'ENABLED' | 'DISABLED' | 'PENDING' | 'DEMO';
interface SiteCreated {
    /**
     * A template identifier (empty if not created from a template).
     * @maxLength 36
     */
    originTemplateId?: string;
    /**
     * An account id of the owner.
     * @format GUID
     */
    ownerId?: string;
    /** A context in which meta site was created. */
    context?: SiteCreatedContextWithLiterals;
    /**
     * A meta site id from which this site was created.
     *
     * In case of a creation from a template it's a template id.
     * In case of a site duplication ("Save As" in dashboard or duplicate in UM) it's an id of a source site.
     * @format GUID
     */
    originMetaSiteId?: string | null;
    /**
     * A meta site name (URL slug).
     * @maxLength 20
     */
    siteName?: string;
    /** A namespace. */
    namespace?: NamespaceWithLiterals;
}
declare enum SiteCreatedContext {
    /** A valid option, we don't expose all reasons why site might be created. */
    OTHER = "OTHER",
    /** A meta site was created from template. */
    FROM_TEMPLATE = "FROM_TEMPLATE",
    /** A meta site was created by copying of the transfferred meta site. */
    DUPLICATE_BY_SITE_TRANSFER = "DUPLICATE_BY_SITE_TRANSFER",
    /** A copy of existing meta site. */
    DUPLICATE = "DUPLICATE",
    /** A meta site was created as a transfferred site (copy of the original), old flow, should die soon. */
    OLD_SITE_TRANSFER = "OLD_SITE_TRANSFER",
    /** deprecated A meta site was created for Flash editor. */
    FLASH = "FLASH"
}
/** @enumType */
type SiteCreatedContextWithLiterals = SiteCreatedContext | 'OTHER' | 'FROM_TEMPLATE' | 'DUPLICATE_BY_SITE_TRANSFER' | 'DUPLICATE' | 'OLD_SITE_TRANSFER' | 'FLASH';
declare enum Namespace {
    UNKNOWN_NAMESPACE = "UNKNOWN_NAMESPACE",
    /** Default namespace for UGC sites. MetaSites with this namespace will be shown in a user's site list by default. */
    WIX = "WIX",
    /** ShoutOut stand alone product. These are siteless (no actual Wix site, no HtmlWeb). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    SHOUT_OUT = "SHOUT_OUT",
    /** MetaSites created by the Albums product, they appear as part of the Albums app. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    ALBUMS = "ALBUMS",
    /** Part of the WixStores migration flow, a user tries to migrate and gets this site to view and if the user likes it then stores removes this namespace and deletes the old site with the old stores. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    WIX_STORES_TEST_DRIVE = "WIX_STORES_TEST_DRIVE",
    /** Hotels standalone (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    HOTELS = "HOTELS",
    /** Clubs siteless MetaSites, a club without a wix website. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    CLUBS = "CLUBS",
    /** A partially created ADI website. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    ONBOARDING_DRAFT = "ONBOARDING_DRAFT",
    /** AppBuilder for AppStudio / shmite (c). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    DEV_SITE = "DEV_SITE",
    /** LogoMaker websites offered to the user after logo purchase. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    LOGOS = "LOGOS",
    /** VideoMaker websites offered to the user after video purchase. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    VIDEO_MAKER = "VIDEO_MAKER",
    /** MetaSites with this namespace will *not* be shown in a user's site list by default. */
    PARTNER_DASHBOARD = "PARTNER_DASHBOARD",
    /** MetaSites with this namespace will *not* be shown in a user's site list by default. */
    DEV_CENTER_COMPANY = "DEV_CENTER_COMPANY",
    /**
     * A draft created by HTML editor on open. Upon "first save" it will be moved to be of WIX domain.
     *
     * Meta site with this namespace will *not* be shown in a user's site list by default.
     */
    HTML_DRAFT = "HTML_DRAFT",
    /**
     * the user-journey for Fitness users who want to start from managing their business instead of designing their website.
     * Will be accessible from Site List and will not have a website app.
     * Once the user attaches a site, the site will become a regular wixsite.
     */
    SITELESS_BUSINESS = "SITELESS_BUSINESS",
    /** Belongs to "strategic products" company. Supports new product in the creator's economy space. */
    CREATOR_ECONOMY = "CREATOR_ECONOMY",
    /** It is to be used in the Business First efforts. */
    DASHBOARD_FIRST = "DASHBOARD_FIRST",
    /** Bookings business flow with no site. */
    ANYWHERE = "ANYWHERE",
    /** Namespace for Headless Backoffice with no editor */
    HEADLESS = "HEADLESS",
    /**
     * Namespace for master site that will exist in parent account that will be referenced by subaccounts
     * The site will be used for account level CSM feature for enterprise
     */
    ACCOUNT_MASTER_CMS = "ACCOUNT_MASTER_CMS",
    /** Rise.ai Siteless account management for Gift Cards and Store Credit. */
    RISE = "RISE",
    /**
     * As part of the branded app new funnel, users now can create a meta site that will be branded app first.
     * There's a blank site behind the scene but it's blank).
     * The Mobile company will be the owner of this namespace.
     */
    BRANDED_FIRST = "BRANDED_FIRST",
    /** Nownia.com Siteless account management for Ai Scheduling Assistant. */
    NOWNIA = "NOWNIA",
    /**
     * UGC Templates are templates that are created by users for personal use and to sale to other users.
     * The Partners company owns this namespace.
     */
    UGC_TEMPLATE = "UGC_TEMPLATE",
    /** Codux Headless Sites */
    CODUX = "CODUX",
    /** Bobb - AI Design Creator. */
    MEDIA_DESIGN_CREATOR = "MEDIA_DESIGN_CREATOR",
    /**
     * Shared Blog Site is a unique single site across Enterprise account,
     * This site will hold all Blog posts related to the Marketing product.
     */
    SHARED_BLOG_ENTERPRISE = "SHARED_BLOG_ENTERPRISE",
    /** Standalone forms (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    STANDALONE_FORMS = "STANDALONE_FORMS",
    /** Standalone events (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    STANDALONE_EVENTS = "STANDALONE_EVENTS",
    /** MIMIR - Siteless account for MIMIR Ai Job runner. */
    MIMIR = "MIMIR"
}
/** @enumType */
type NamespaceWithLiterals = Namespace | 'UNKNOWN_NAMESPACE' | 'WIX' | 'SHOUT_OUT' | 'ALBUMS' | 'WIX_STORES_TEST_DRIVE' | 'HOTELS' | 'CLUBS' | 'ONBOARDING_DRAFT' | 'DEV_SITE' | 'LOGOS' | 'VIDEO_MAKER' | 'PARTNER_DASHBOARD' | 'DEV_CENTER_COMPANY' | 'HTML_DRAFT' | 'SITELESS_BUSINESS' | 'CREATOR_ECONOMY' | 'DASHBOARD_FIRST' | 'ANYWHERE' | 'HEADLESS' | 'ACCOUNT_MASTER_CMS' | 'RISE' | 'BRANDED_FIRST' | 'NOWNIA' | 'UGC_TEMPLATE' | 'CODUX' | 'MEDIA_DESIGN_CREATOR' | 'SHARED_BLOG_ENTERPRISE' | 'STANDALONE_FORMS' | 'STANDALONE_EVENTS' | 'MIMIR';
/** Site transferred to another user. */
interface SiteTransferred {
    /**
     * A previous owner id (user that transfers meta site).
     * @format GUID
     */
    oldOwnerId?: string;
    /**
     * A new owner id (user that accepts meta site).
     * @format GUID
     */
    newOwnerId?: string;
}
/** Soft deletion of the meta site. Could be restored. */
interface SiteDeleted {
    /** A deletion context. */
    deleteContext?: DeleteContext;
}
interface DeleteContext {
    /** When the meta site was deleted. */
    dateDeleted?: Date | null;
    /** A status. */
    deleteStatus?: DeleteStatusWithLiterals;
    /**
     * A reason (flow).
     * @maxLength 255
     */
    deleteOrigin?: string;
    /**
     * A service that deleted it.
     * @maxLength 255
     */
    initiatorId?: string | null;
}
declare enum DeleteStatus {
    UNKNOWN = "UNKNOWN",
    TRASH = "TRASH",
    DELETED = "DELETED",
    PENDING_PURGE = "PENDING_PURGE",
    PURGED_EXTERNALLY = "PURGED_EXTERNALLY"
}
/** @enumType */
type DeleteStatusWithLiterals = DeleteStatus | 'UNKNOWN' | 'TRASH' | 'DELETED' | 'PENDING_PURGE' | 'PURGED_EXTERNALLY';
/** Restoration of the meta site. */
interface SiteUndeleted {
}
/** First publish of a meta site. Or subsequent publish after unpublish. */
interface SitePublished {
}
interface SiteUnpublished {
    /**
     * A list of URLs previously associated with the meta site.
     * @maxLength 4000
     * @maxSize 10000
     */
    urls?: string[];
}
interface SiteMarkedAsTemplate {
}
interface SiteMarkedAsWixSite {
}
/**
 * Represents a service provisioned a site.
 *
 * Note on `origin_instance_id`:
 * There is no guarantee that you will be able to find a meta site using `origin_instance_id`.
 * This is because of the following scenario:
 *
 * Imagine you have a template where a third-party application (TPA) includes some stub data,
 * such as a product catalog. When you create a site from this template, you inherit this
 * default product catalog. However, if the template's product catalog is modified,
 * your site will retain the catalog as it was at the time of site creation. This ensures that
 * your site remains consistent with what you initially received and does not include any
 * changes made to the original template afterward.
 * To ensure this, the TPA on the template gets a new instance_id.
 */
interface ServiceProvisioned {
    /**
     * Either UUID or EmbeddedServiceType.
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * Not only UUID. Something here could be something weird.
     * @maxLength 36
     */
    instanceId?: string;
    /**
     * An instance id from which this instance is originated.
     * @maxLength 36
     */
    originInstanceId?: string;
    /**
     * A version.
     * @maxLength 500
     */
    version?: string | null;
    /**
     * The origin meta site id
     * @format GUID
     */
    originMetaSiteId?: string | null;
}
interface ServiceRemoved {
    /**
     * Either UUID or EmbeddedServiceType.
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * Not only UUID. Something here could be something weird.
     * @maxLength 36
     */
    instanceId?: string;
    /**
     * A version.
     * @maxLength 500
     */
    version?: string | null;
}
/** Rename of the site. Meaning, free public url has been changed as well. */
interface SiteRenamed {
    /**
     * A new meta site name (URL slug).
     * @maxLength 20
     */
    newSiteName?: string;
    /**
     * A previous meta site name (URL slug).
     * @maxLength 255
     */
    oldSiteName?: string;
}
/**
 * Hard deletion of the meta site.
 *
 * Could not be restored. Therefore it's desirable to cleanup data.
 */
interface SiteHardDeleted {
    /** A deletion context. */
    deleteContext?: DeleteContext;
}
interface NamespaceChanged {
    /** A previous namespace. */
    oldNamespace?: NamespaceWithLiterals;
    /** A new namespace. */
    newNamespace?: NamespaceWithLiterals;
}
/** Assigned Studio editor */
interface StudioAssigned {
}
/** Unassigned Studio editor */
interface StudioUnassigned {
}
/**
 * Fired in case site URLs were changed in any way: new secondary domain, published, account slug rename, site rename etc.
 *
 * This is an internal event, it's not propagated in special events, because it's non-actionable. If you need to keep up
 * with sites and its urls, you need to listen to another topic/event. Read about it:
 *
 * https://bo.wix.com/wix-docs/rest/meta-site/meta-site---urls-service
 */
interface SiteUrlChanged {
}
/**
 * Used at the end of the deletion flow for both draft sites and when a user deletes a site.
 * Consumed by other teams to remove relevant data.
 */
interface SitePurgedExternally {
    /**
     * @maxLength 2048
     * @maxSize 100
     * @deprecated
     * @targetRemovalDate 2025-04-15
     */
    appDefId?: string[];
}
/** Assigned Odeditor */
interface OdeditorAssigned {
}
/** Unassigned Odeditor */
interface OdeditorUnassigned {
}
/** Assigned Picasso editor */
interface PicassoAssigned {
}
/** Unassigned Picasso */
interface PicassoUnassigned {
}
interface HtmlSitePublished {
    /**
     * Application instance ID
     * @maxLength 50
     */
    appInstanceId?: string;
    /**
     * Application type
     * @maxLength 100
     */
    appType?: string;
    /** Revision */
    revision?: string;
    /**
     * MSID
     * @maxLength 100
     */
    metaSiteId?: string | null;
    /**
     * optional branch id if publish is done from branch
     * @format GUID
     */
    branchId?: string | null;
    /** The site's last transactionId */
    lastTransactionId?: string | null;
    /** A list of the site's pages */
    pages?: Page[];
    /** Site's publish date */
    publishDate?: string;
}
interface Page {
    /**
     * Page's Id
     * @maxLength 100
     */
    _id?: string;
}
interface SubscriptionEvent extends SubscriptionEventEventOneOf {
    /** Triggered when a subscription is created. */
    created?: SubscriptionCreated;
    /**
     * Triggered when a subscription is assigned to a Wix site, including the initial
     * assignment of a floating subscription or a re-assignement from a different site.
     */
    assigned?: SubscriptionAssigned;
    /** Triggered when a subscription is canceled. */
    cancelled?: SubscriptionCancelled;
    /** Triggered when the subscription's auto renew is turned on. */
    autoRenewTurnedOn?: SubscriptionAutoRenewTurnedOn;
    /** Triggered when the subscription's auto renew is turned off. */
    autoRenewTurnedOff?: SubscriptionAutoRenewTurnedOff;
    /**
     * Triggered when a subscription is unassigned from a Wix site and becomes
     * floating.
     */
    unassigned?: SubscriptionUnassigned;
    /**
     * Triggered when a subscription is transferred from one Wix account to another.
     * A transfer includes cancelling the original subscription and creating a new
     * subscription for the target account. The event returns both the original
     * and the new subscription.
     */
    transferred?: SubscriptionTransferred;
    /** Triggered when a recurring charge succeeds for a subscription. */
    recurringChargeSucceeded?: RecurringChargeSucceeded;
    /**
     * Triggered when a subscription was updated including when its product has been
     * up- or downgraded or the billing cycle is changed.
     */
    contractSwitched?: ContractSwitched;
    /**
     * Triggered when a subscription gets close to the end of its billing cycle.
     * The exact number of days is defined in the billing system.
     */
    nearEndOfPeriod?: SubscriptionNearEndOfPeriod;
    /**
     * Triggered when a subscription is updated and the change doesn't happen
     * immediately but at the end of the current billing cycle.
     */
    pendingChange?: SubscriptionPendingChange;
    /** Triggered when a recurring charge attempt fails for a subscription. */
    recurringChargeAttemptFailed?: RecurringChargeAttemptFailed;
    /**
     * ID of the subscription's event.
     * @format GUID
     */
    eventId?: string | null;
    /**
     * Date and time of the event in
     * [UTC datetime](https://en.wikipedia.org/wiki/Coordinated_Universal_Time)
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     */
    eventDate?: Date | null;
}
/** @oneof */
interface SubscriptionEventEventOneOf {
    /** Triggered when a subscription is created. */
    created?: SubscriptionCreated;
    /**
     * Triggered when a subscription is assigned to a Wix site, including the initial
     * assignment of a floating subscription or a re-assignement from a different site.
     */
    assigned?: SubscriptionAssigned;
    /** Triggered when a subscription is canceled. */
    cancelled?: SubscriptionCancelled;
    /** Triggered when the subscription's auto renew is turned on. */
    autoRenewTurnedOn?: SubscriptionAutoRenewTurnedOn;
    /** Triggered when the subscription's auto renew is turned off. */
    autoRenewTurnedOff?: SubscriptionAutoRenewTurnedOff;
    /**
     * Triggered when a subscription is unassigned from a Wix site and becomes
     * floating.
     */
    unassigned?: SubscriptionUnassigned;
    /**
     * Triggered when a subscription is transferred from one Wix account to another.
     * A transfer includes cancelling the original subscription and creating a new
     * subscription for the target account. The event returns both the original
     * and the new subscription.
     */
    transferred?: SubscriptionTransferred;
    /** Triggered when a recurring charge succeeds for a subscription. */
    recurringChargeSucceeded?: RecurringChargeSucceeded;
    /**
     * Triggered when a subscription was updated including when its product has been
     * up- or downgraded or the billing cycle is changed.
     */
    contractSwitched?: ContractSwitched;
    /**
     * Triggered when a subscription gets close to the end of its billing cycle.
     * The exact number of days is defined in the billing system.
     */
    nearEndOfPeriod?: SubscriptionNearEndOfPeriod;
    /**
     * Triggered when a subscription is updated and the change doesn't happen
     * immediately but at the end of the current billing cycle.
     */
    pendingChange?: SubscriptionPendingChange;
    /** Triggered when a recurring charge attempt fails for a subscription. */
    recurringChargeAttemptFailed?: RecurringChargeAttemptFailed;
}
/** Triggered when a subscription is created. */
interface SubscriptionCreated {
    /** Created subscription. */
    subscription?: Subscription;
    /** Metadata for the `created` event. */
    metadata?: Record<string, string>;
    /**
     * Subscription reactivation data.
     * A subscription can be reactivated for example if it was incorrectly canceled because of fraud and then reactivated
     * by the billing system
     */
    reactivationData?: ReactivationData;
}
/**
 * A subscription holds information about a Premium product that a Wix account
 * owner has purchased including details about the billing.
 */
interface Subscription {
    /**
     * ID of the subscription.
     * @format GUID
     */
    _id?: string;
    /**
     * ID of the Wix account that purchased the subscription.
     * @format GUID
     */
    userId?: string;
    /**
     * ID of the [product](https://bo.wix.com/wix-docs/rest/premium/premium-product-catalog-v2/products/product-object)
     * for which the subscription was purchased.
     * @format GUID
     */
    productId?: string;
    /**
     * Date and time the subscription was created in
     * [UTC datetime](https://en.wikipedia.org/wiki/Coordinated_Universal_Time)
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     */
    createdAt?: Date | null;
    /**
     * Date and time the subscription was last updated in
     * [UTC datetime](https://en.wikipedia.org/wiki/Coordinated_Universal_Time)
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     */
    updatedAt?: Date | null;
    /**
     * ID of the metasite that the subscription is assigned to.
     * Available only when the subscription is assigned to a Wix site.
     * Subscriptions for account level products can't be assigned to a Wix site.
     * @format GUID
     */
    metaSiteId?: string | null;
    /** Information about the system that manages the subscription's billing. */
    billingReference?: BillingReference;
    /** Information about the billing cycle of the subscription. */
    cycle?: Cycle;
    /**
     * Subscription status.
     *
     * + `UNKNOWN`: Default status.
     * + `AUTO_RENEW_ON`: Subscription is active and automatically renews at the end of the current billing cycle.
     * + `AUTO_RENEW_OFF`: Subscription is active but expires at the end of the current billing cycle.
     * + `MANUAL_RECURRING`: Subscription is active and renews at the end of the current billing cycle, in case the customer takes an action related to the payment.
     * + `CANCELLED`: Subscription isn't active because it has been canceled.
     * + `TRANSFERRED`: Subscription isn't active because it has been transferred to a different account. A different active subscription was created for the target account.
     */
    status?: SubscriptionStatusWithLiterals;
    /**
     * Date and time the subscription was last transferred from one Wix account to
     * another in
     * [UTC datetime](https://en.wikipedia.org/wiki/Coordinated_Universal_Time)
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     */
    transferredAt?: Date | null;
    /**
     * ID of the [product type](https://bo.wix.com/wix-docs/rest/premium/premium-product-catalog-v2/product-types/product-type-object)
     * that the product, for which the subscription was purchased, belongs to.
     * @format GUID
     */
    productTypeId?: string;
    /** Version number, which increments by 1 each time the subscription is updated. */
    version?: number;
    /**
     * Whether the subscription is active. Includes the statuses
     * `"AUTO_RENEW_ON"`, `"AUTO_RENEW_OFF"`, and `"MANUAL_RECURRING"`.
     */
    active?: boolean;
    /**
     * Date and time the subscription was originally created in
     * [UTC datetime](https://en.wikipedia.org/wiki/Coordinated_Universal_Time)
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     * Differs from `createdAt` in case the subscription was originally created for a different Wix account and has been transferred.
     */
    originalCreationDate?: Date | null;
    /** Custom metadata about the subscription. */
    metadata?: Record<string, string>;
    /**
     * 2-letter country code in
     * [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements)
     * format.
     */
    countryCode?: string | null;
    /**
     * Seats of the product that the subscription was purchased for.
     * Will be Null for products that don't support seats.
     * @min 1
     * @max 500
     */
    seats?: number | null;
}
interface BillingReference {
    /**
     * Name of the billing system that manages the subscription.
     *
     * + `"UNKNOWN"`: Default value.
     * + `"SBS"`: [Wix Billing](https://github.com/wix-p/premium-billing/tree/master/sbs).
     * + `"LICENSER"`:
     * + `"BASS"`: [Billing and Subscriptions System](https://dev.wix.com/docs/rest/internal-only/premium/subscriptions-by-billing-by-wix/introduction).
     * + `"RESELLER"`: [External Reseller](https://dev.wix.com/api/rest/account-level-apis/resellers/introduction).
     */
    providerName?: ProviderNameWithLiterals;
    /** Current provider reference ID. */
    providerReferenceId?: string | null;
    /** Previous provider reference IDs. Used for when a subscription is extended, specifically for domains. */
    previousProviderReferenceIds?: string[];
}
declare enum ProviderName {
    UNKNOWN = "UNKNOWN",
    SBS = "SBS",
    LICENSER = "LICENSER",
    BASS = "BASS",
    RESELLER = "RESELLER",
    RECURRING_INVOICES = "RECURRING_INVOICES"
}
/** @enumType */
type ProviderNameWithLiterals = ProviderName | 'UNKNOWN' | 'SBS' | 'LICENSER' | 'BASS' | 'RESELLER' | 'RECURRING_INVOICES';
interface Cycle extends CycleCycleSelectorOneOf {
    /** repetitive interval */
    interval?: Interval;
    /** one time */
    oneTime?: OneTime;
}
/** @oneof */
interface CycleCycleSelectorOneOf {
    /** repetitive interval */
    interval?: Interval;
    /** one time */
    oneTime?: OneTime;
}
interface Interval {
    /** interval unit of measure */
    unit?: IntervalUnitWithLiterals;
    /** number of interval */
    count?: number;
}
declare enum IntervalUnit {
    /** unknown interval unit */
    UNKNOWN = "UNKNOWN",
    /** day */
    DAY = "DAY",
    /** week */
    WEEK = "WEEK",
    /** month */
    MONTH = "MONTH",
    /** year */
    YEAR = "YEAR"
}
/** @enumType */
type IntervalUnitWithLiterals = IntervalUnit | 'UNKNOWN' | 'DAY' | 'WEEK' | 'MONTH' | 'YEAR';
interface OneTime {
}
declare enum SubscriptionStatus {
    UNKNOWN = "UNKNOWN",
    AUTO_RENEW_ON = "AUTO_RENEW_ON",
    AUTO_RENEW_OFF = "AUTO_RENEW_OFF",
    MANUAL_RECURRING = "MANUAL_RECURRING",
    CANCELLED = "CANCELLED",
    TRANSFERRED = "TRANSFERRED"
}
/** @enumType */
type SubscriptionStatusWithLiterals = SubscriptionStatus | 'UNKNOWN' | 'AUTO_RENEW_ON' | 'AUTO_RENEW_OFF' | 'MANUAL_RECURRING' | 'CANCELLED' | 'TRANSFERRED';
/** Triggered when a subscription is reactivated. */
interface ReactivationData {
    reactivationReason?: ReactivationReasonEnumWithLiterals;
    /**
     * In the event of reactivation after chargeback dispute, the subscription may be extended according to the
     * number of days it was inactive during the time of resolving the dispute
     */
    newEndOfPeriod?: Date | null;
    /** The original end date, before the inactive period. */
    oldEndOfPeriod?: Date | null;
    /** The difference in days between the new new_end_of_period and old_end_of_period */
    differenceInDays?: number | null;
}
/** Reason for subscription reactivation */
declare enum ReactivationReasonEnum {
    UNKNOWN = "UNKNOWN",
    /**
     * Subscription was reactivated due to billing status change from CANCELED to ACTIVE, for example if it was incorrectly
     * canceled because of suspicion of fraud
     */
    BILLING_STATUS_CHANGE = "BILLING_STATUS_CHANGE",
    /** Subscription was reactivated after a chargeback dispute */
    REACTIVATED_AFTER_CHARGEBACK = "REACTIVATED_AFTER_CHARGEBACK"
}
/** @enumType */
type ReactivationReasonEnumWithLiterals = ReactivationReasonEnum | 'UNKNOWN' | 'BILLING_STATUS_CHANGE' | 'REACTIVATED_AFTER_CHARGEBACK';
/**
 * Triggered when a subscription is assigned to a Wix site, including the initial
 * assignment of a floating subscription or a re-assignement from a different site.
 */
interface SubscriptionAssigned {
    /** Assigned subscription. */
    subscription?: Subscription;
    /**
     * ID of the metasite that the subscription has been assigned to before the update.
     * @format GUID
     */
    previousMetaSiteId?: string | null;
}
/** Triggered when a subscription is canceled. */
interface SubscriptionCancelled {
    /** Canceled subscription. */
    subscription?: Subscription;
    /** Details about the cancellation including who canceled the subscription and why. */
    cancellationDetails?: CancellationDetails;
    /**
     * Whether the subscription is canceled immediately or expires at the end of the current billing cycle.
     *
     * Default: `false`
     */
    immediateCancel?: boolean;
    /** Whether the subscription was canceled during the free trial period. */
    canceledInFreeTrial?: boolean;
}
/** Information about the cancellation flow including who canceled the subscription and why it was canceled. */
interface CancellationDetails {
    /**
     * Cancellation code.
     *
     * Values supported for cancellations on behalf of the billing system: `-1`, `-2`, `-3`, `-4`, `-5`, `-6`, `-7`, `-8`.
     * For cancellations on behalf of the site owner or the service provider `cancellationCode`
     * is taken from the request of
     * [Cancel Immediately Offline](https://bo.wix.com/wix-docs/rest/premium/premium-subscriptions-manager/cancel-immediately-offline).
     *
     * + `-1`: The subscription has been cancelled by the billing system but none of the listed cancellation reasons applies.
     * + `-2`: There were payment problems.
     * + `-3`: There was a chargeback.
     * + `-4`: Customer support has canceled the subscription and issued a refund.
     * + `-5`: The site owner has changed their existing subscription.
     * + `-6`: The subscription has been transferred to a different Wix account.
     * + `-7`: The subscription has been canceled because the site owner hasn't manually authenticated the recurring payment during the subscription's grace period. For example, site owners must manually confirm recurring payments within 40 days when paying with boleto.
     * + `-8`: The Wix account that the subscription belonged to has been deleted.
     */
    cancellationCode?: number | null;
    /**
     * Cancellation reason. For cancellations on behalf of the site owner or the service provider `cancellationReason`
     * is taken from the request of
     * [Cancel Immediately Offline](https://bo.wix.com/wix-docs/rest/premium/premium-subscriptions-manager/cancel-immediately-offline).
     * For cancellations on behalf of the billing system `cancellationReason` is `null` or an empty string.
     */
    cancellationReason?: string | null;
    /**
     * Initiator of the cancellation. For `"USER_REQUESTED"` and `"APP_MANAGED"`,
     * `cancellationCode` and `cancellationReason` are taken from the request of
     * [Cancel Immediately](https://dev.wix.com/docs/rest/account-level/premium/premium-subscriptions-manager/subscription-v1/cancel-immediately)
     * or [Cancel Immediately Offline](https://dev.wix.com/docs/rest/account-level/premium/premium-subscriptions-manager/subscription-v1/cancel-immediately-offline).
     * For `"PASSIVE"`, cancellations `cancellationCode` is automatically calculated and `cancellationReason`
     * is `null` or an empty string.
     *
     * + `"UNKNOWN`: Default value.
     * + `"USER_REQUESTED"`:  The Wix account owner has canceled the subscription.
     * + `"APP_MANAGED"`: The service provider has canceled the subscription.
     * + `"PASSIVE"`: The billing system has canceled the subscription. For example, in case of payment failure or fraud.
     */
    initiator?: InitiatorWithLiterals;
}
declare enum Initiator {
    UNKNOWN = "UNKNOWN",
    USER_REQUESTED = "USER_REQUESTED",
    APP_MANAGED = "APP_MANAGED",
    PASSIVE = "PASSIVE"
}
/** @enumType */
type InitiatorWithLiterals = Initiator | 'UNKNOWN' | 'USER_REQUESTED' | 'APP_MANAGED' | 'PASSIVE';
/** Triggered when the subscription's auto renew is turned on. */
interface SubscriptionAutoRenewTurnedOn {
    /** Subscription for which auto renew is turned on. */
    subscription?: Subscription;
    /**
     * Supported values: `USER`, `APP`.
     *
     * Information about who turned auto renew on.
     * + `"USER"`: The site owner who purchased the subscription has turned auto renew on.
     * + `"APP"`: The service provider has turned auto renew on.
     */
    initiator?: string | null;
}
/** Triggered when the subscription's auto renew is turned off. */
interface SubscriptionAutoRenewTurnedOff {
    /** Subscription for which auto renew is turned off. */
    subscription?: Subscription;
    /** Details about the cancellation including who canceled the subscription and why. */
    cancellationDetails?: CancellationDetails;
    /**
     * Whether the subscription is immediately canceled or expires at the end of the current billing cycle.
     *
     * Default: `false`
     */
    immediateCancel?: boolean;
}
/**
 * Triggered when a subscription is unassigned from a Wix site and becomes
 * floating.
 */
interface SubscriptionUnassigned {
    /** Unassigned subscription. */
    subscription?: Subscription;
    /**
     * ID of the metasite that the subscription has been assigned to before the event.
     * @format GUID
     */
    previousMetaSiteId?: string;
    /**
     * Reason why the subscription is unassigned.
     *
     * + `"UNKNOWN"`: Default value.
     * + `"USER_REQUESTED"`: The Wix account owner has unassigned the subscription.
     * + `"REPLACED_BY_ANOTHER_SUBSCRIPTION"`: A different subscription that replaces this subscription is assigned to the site.
     */
    unassignReason?: UnassignReasonWithLiterals;
}
declare enum UnassignReason {
    UNKNOWN = "UNKNOWN",
    USER_REQUESTED = "USER_REQUESTED",
    REPLACED_BY_ANOTHER_SUBSCRIPTION = "REPLACED_BY_ANOTHER_SUBSCRIPTION"
}
/** @enumType */
type UnassignReasonWithLiterals = UnassignReason | 'UNKNOWN' | 'USER_REQUESTED' | 'REPLACED_BY_ANOTHER_SUBSCRIPTION';
/**
 * Triggered when a subscription is transferred from one Wix account to another.
 * A transfer includes cancelling the original subscription and creating a new
 * subscription for the target account. The event returns both the original
 * and the new subscription.
 */
interface SubscriptionTransferred {
    /** Original subscription that was canceled for the transfer. */
    originSubscription?: Subscription;
    /** Newly created subscription for the target account. */
    targetSubscription?: Subscription;
}
/** Triggered when a recurring charge succeeds for a subscription. */
interface RecurringChargeSucceeded {
    /** Subscription for which the recurring charge has succeeded. */
    subscription?: Subscription;
    /** Indication that there was a successful charge at the end of the free trial period */
    freeTrialPeriodEnd?: boolean;
}
/**
 * Triggered when a subscription was updated including when its product has been
 * up- or downgraded or the billing cycle is changed.
 */
interface ContractSwitched {
    /** Updated subscription. */
    subscription?: Subscription;
    /** Billing cycle before the update. */
    previousCycle?: Cycle;
    /**
     * ID of the product belonging to the subscription before the update.
     * @format GUID
     */
    previousProductId?: string;
    /**
     * ID of the product type that the subscription's original product belonged to before the update.
     * @format GUID
     */
    previousProductTypeId?: string;
    /**
     * Update type. __Note__: Doesn't include information about a product adjustment.
     * For that purpose, see `productAdjustment`.
     *
     * + `"NOT_APPLICABLE"`: Default value.
     * + `"ADDITIONAL_QUANTITY"`: An increased usage quota is added to the subscription. For example, a second mailbox is added to a subscription that previously included a single mailbox.
     * + `"CREDIT_UNUSED_PERIOD"`: The subscription is upgraded and the new price is less than the regular price. The new price applies to every billing cycle, not just the first cycle.
     * + `"REFUND_PRICE_DIFF"`: Not implemented.
     * + `"ADJUST_PERIOD_END"`: Not implemented.
     * + `"DOWNGRADE_GRACE_PERIOD"`: For downgrades during the grace period. In this situation, the site owner hasn’t paid yet and must immediately pay for the downgraded subscription.
     * + `"FULL_AMOUNT_PERIOD"`: For upgrades in which the site owner retains unused benefits. For example, site owners upgrading a Facebook Ads subscription retain their unused FB Ads credit. The unused credit is added to the new credit.
     * + `"END_OF_PERIOD"`: The subscription's billing current cycle is extended because of a downgrade.
     * + `"PENDING_CHANGES"`: The subscription's billing is updated, but the change doesn't apply immediately. Instead, the update becomes effective at the end of current billing cycle.
     * + `"DOWNGRADE_RENEWAL"`: The subscription is downgraded because of a declined payment. This prevents subscriptions from churning.
     */
    contractSwitchType?: ContractSwitchTypeWithLiterals;
    /**
     * ID of the metasite the subscription has been assigned to previously.
     * Available only in case the subscription is assigned to a different site.
     * @format GUID
     */
    previousMetaSiteId?: string | null;
    /**
     * Update reason.
     *
     * + `"PRICE_INCREASE"`: The subscription's price has been increased.
     * + `"EXTERNAL_PROVIDER_TRIGGER"`: Any reason other than a price increase.
     */
    contractSwitchReason?: ContractSwitchReasonWithLiterals;
    /** Information about the price update. Available only for updates with a price increase. */
    productPriceIncreaseData?: ProductPriceIncreaseData;
    /**
     * Information about a product adjustment. For example, a downgrade.
     * __Note__: This isn't the same as `contractSwitchType`.
     *
     * + `NOT_APPLICABLE`: There is no information about whether the product has been up- or downgraded.
     * + `DOWNGRADE`: The product has been downgraded.
     */
    productAdjustment?: ProductAdjustmentWithLiterals;
}
/** Copied from SBS */
declare enum ContractSwitchType {
    NOT_APPLICABLE = "NOT_APPLICABLE",
    ADDITIONAL_QUANTITY = "ADDITIONAL_QUANTITY",
    CREDIT_UNUSED_PERIOD = "CREDIT_UNUSED_PERIOD",
    REFUND_PRICE_DIFF = "REFUND_PRICE_DIFF",
    ADJUST_PERIOD_END = "ADJUST_PERIOD_END",
    DOWNGRADE_GRACE_PERIOD = "DOWNGRADE_GRACE_PERIOD",
    FULL_AMOUNT_PERIOD = "FULL_AMOUNT_PERIOD",
    END_OF_PERIOD = "END_OF_PERIOD",
    PENDING_CHANGES = "PENDING_CHANGES",
    DOWNGRADE_RENEWAL = "DOWNGRADE_RENEWAL"
}
/** @enumType */
type ContractSwitchTypeWithLiterals = ContractSwitchType | 'NOT_APPLICABLE' | 'ADDITIONAL_QUANTITY' | 'CREDIT_UNUSED_PERIOD' | 'REFUND_PRICE_DIFF' | 'ADJUST_PERIOD_END' | 'DOWNGRADE_GRACE_PERIOD' | 'FULL_AMOUNT_PERIOD' | 'END_OF_PERIOD' | 'PENDING_CHANGES' | 'DOWNGRADE_RENEWAL';
declare enum ContractSwitchReason {
    EXTERNAL_PROVIDER_TRIGGER = "EXTERNAL_PROVIDER_TRIGGER",
    PRICE_INCREASE = "PRICE_INCREASE"
}
/** @enumType */
type ContractSwitchReasonWithLiterals = ContractSwitchReason | 'EXTERNAL_PROVIDER_TRIGGER' | 'PRICE_INCREASE';
/** Triggered when a subscription's price is increased. */
interface ProductPriceIncreaseData {
    /**
     * Price of the subscription before the update.
     * @format DECIMAL_VALUE
     */
    previousPrice?: string | null;
    /** A value that is used in order to select the correct email template to send the user regarding the price increase. */
    emailTemplateSelector?: string | null;
    /** Used to differentiate between migration segments. Does not have to be unique per segment. */
    segmentName?: string | null;
    /** Used to determine how the price increase was triggered. */
    priceIncreaseTrigger?: PriceIncreaseTriggerWithLiterals;
}
/** Reason for Price Increase Trigger */
declare enum PriceIncreaseTrigger {
    NEAR_RENEWAL = "NEAR_RENEWAL",
    RECURRING_SUCCESS = "RECURRING_SUCCESS",
    MANUAL = "MANUAL"
}
/** @enumType */
type PriceIncreaseTriggerWithLiterals = PriceIncreaseTrigger | 'NEAR_RENEWAL' | 'RECURRING_SUCCESS' | 'MANUAL';
/** Triggered when a subscription's product is adusted. */
declare enum ProductAdjustment {
    /** flag to show that the ContractSwitchedEvent is not applicable / needed */
    NOT_APPLICABLE = "NOT_APPLICABLE",
    /** flag to show that the ContractSwitchedEvent is a Downgrade */
    DOWNGRADE = "DOWNGRADE"
}
/** @enumType */
type ProductAdjustmentWithLiterals = ProductAdjustment | 'NOT_APPLICABLE' | 'DOWNGRADE';
/**
 * Triggered when a subscription gets close to the end of its billing cycle.
 * The exact number of days is defined in the billing system.
 */
interface SubscriptionNearEndOfPeriod {
    /** Subscription that got close to the end of its billing cycle. */
    subscription?: Subscription;
    /** Whether the subscription is within the free trial period. */
    inFreeTrial?: boolean;
}
/**
 * Triggered when a subscription is updated and the change doesn't happen
 * immediately but at the end of the current billing cycle.
 */
interface SubscriptionPendingChange {
    /** Subscription for which a pending update is triggered. */
    subscription?: Subscription;
}
/** Triggered when a recurring charge attempt failed for a subscription. */
interface RecurringChargeAttemptFailed {
    /** Subscription for which the recurring charge attempt has failed. */
    subscription?: Subscription;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface ProgramUpdatedEnvelope {
    entity: ReferralProgram;
    metadata: EventMetadata;
}
/**
 * Triggered when a referral program is updated.
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Referrals
 * @permissionScopeId SCOPE.DC-REFERRALS.MANAGE-REFERRALS
 * @permissionId REFERRALS.READ_PROGRAM
 * @webhook
 * @eventType wix.loyalty.referral.v1.program_updated
 * @serviceIdentifier wix.loyalty.referral.program.v1.ReferralPrograms
 * @slug updated
 */
declare function onProgramUpdated(handler: (event: ProgramUpdatedEnvelope) => void | Promise<void>): void;
type ProgramNonNullablePaths = `status` | `referredFriendReward.couponOptions.fixedAmountOptions.amount` | `referredFriendReward.couponOptions.percentageOptions.percentage` | `referredFriendReward.couponOptions.minimumSubtotal` | `referredFriendReward.couponOptions.scope.namespace` | `referredFriendReward.couponOptions.scope.group.name` | `referredFriendReward.couponOptions.name` | `referredFriendReward.couponOptions.discountType` | `referredFriendReward.loyaltyPointsOptions.amount` | `referredFriendReward.type` | `referringCustomerReward.couponOptions.fixedAmountOptions.amount` | `referringCustomerReward.couponOptions.percentageOptions.percentage` | `referringCustomerReward.couponOptions.minimumSubtotal` | `referringCustomerReward.couponOptions.scope.namespace` | `referringCustomerReward.couponOptions.scope.group.name` | `referringCustomerReward.couponOptions.name` | `referringCustomerReward.couponOptions.discountType` | `referringCustomerReward.loyaltyPointsOptions.amount` | `referringCustomerReward.type` | `successfulReferralActions` | `emails.encourageToReferFriends` | `emails.notifyCustomersAboutReward` | `premiumFeatures.referralProgram`;
/**
 * Retrieves the referral program.
 * @public
 * @permissionId REFERRALS.READ_PROGRAM
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.loyalty.referral.program.v1.ReferralPrograms.GetReferralProgram
 */
declare function getReferralProgram(): Promise<NonNullablePaths<GetReferralProgramResponse, {
    [P in ProgramNonNullablePaths]: `referralProgram.${P}`;
}[ProgramNonNullablePaths]>>;
/**
 * Retrieves multiple referral programs for all metasites that the caller is the member of.
 *
 * Must be called with a [user identity](https://dev.wix.com/docs/build-apps/develop-your-app/access/about-identities#identity-types).
 * @internal
 * @documentationMaturity preview
 * @permissionId REFERRALS.PROGRAM_BULK_READ
 * @fqn wix.loyalty.referral.program.v1.ReferralPrograms.BulkGetReferralProgram
 */
declare function bulkGetReferralProgram(): Promise<NonNullablePaths<BulkGetReferralProgramResponse, `programInSites` | `programInSites.${number}.metaSiteId` | {
    [P in ProgramNonNullablePaths]: `programInSites.${number}.referralProgram.${P}`;
}[ProgramNonNullablePaths]>>;
/**
 * Updates a referral program. Supports partial updates.
 *
 * Revision number, which increments by 1 each time the referral program is updated.
 * To prevent conflicting changes, the current revision must be passed when updating the referral program.
 * @param referralProgram - Referral program to update. Include the latest `revision` for a successful update.
 * @public
 * @requiredField referralProgram
 * @requiredField referralProgram.revision
 * @permissionId REFERRALS.MANAGE_PROGRAM
 * @applicableIdentity APP
 * @fqn wix.loyalty.referral.program.v1.ReferralPrograms.UpdateReferralProgram
 */
declare function updateReferralProgram(referralProgram: NonNullablePaths<ReferralProgram, `revision`>): Promise<NonNullablePaths<UpdateReferralProgramResponse, {
    [P in ProgramNonNullablePaths]: `referralProgram.${P}`;
}[ProgramNonNullablePaths]>>;
/**
 * Activates the referral program, changing its status to `ACTIVE`.
 * @public
 * @permissionId REFERRALS.MANAGE_PROGRAM
 * @applicableIdentity APP
 * @fqn wix.loyalty.referral.program.v1.ReferralPrograms.ActivateReferralProgram
 */
declare function activateReferralProgram(): Promise<NonNullablePaths<ActivateReferralProgramResponse, {
    [P in ProgramNonNullablePaths]: `referralProgram.${P}`;
}[ProgramNonNullablePaths]>>;
/**
 * Pauses the referral program, changing its status to `PAUSED`.
 * @public
 * @permissionId REFERRALS.MANAGE_PROGRAM
 * @applicableIdentity APP
 * @fqn wix.loyalty.referral.program.v1.ReferralPrograms.PauseReferralProgram
 */
declare function pauseReferralProgram(): Promise<NonNullablePaths<PauseReferralProgramResponse, {
    [P in ProgramNonNullablePaths]: `referralProgram.${P}`;
}[ProgramNonNullablePaths]>>;
/**
 * Retrieves pre-generated AI social media post suggestions for promoting the referral program.
 *
 * This method returns a list of AI-generated social media post suggestions that site owners or members can use to promote the referral program. You can display these suggestions to allow referring customers to easily copy and share them on their preferred social media platforms.
 *
 * >**Note**: This method retrieves existing suggestions. To generate new ones,
 * use Generate AI Social Media Posts Suggestions.
 * @public
 * @permissionId REFERRALS.MANAGE_PROGRAM
 * @applicableIdentity APP
 * @fqn wix.loyalty.referral.program.v1.ReferralPrograms.GetAISocialMediaPostsSuggestions
 */
declare function getAiSocialMediaPostsSuggestions(options?: GetAiSocialMediaPostsSuggestionsOptions): Promise<NonNullablePaths<GetAISocialMediaPostsSuggestionsResponse, `suggestions` | `suggestions.${number}.postContent`>>;
interface GetAiSocialMediaPostsSuggestionsOptions {
    /**
     * Topic to generate social media post suggestions for. For example, fitness, education, or technology.
     * @maxLength 512
     */
    topic?: string;
}
/**
 * Creates new AI-generated social media post suggestions for promoting the referral program.
 *
 * This method generates new AI-powered social media post suggestions for promoting the referral program. Use it to refresh content or create alternatives to existing suggestions.
 *
 * >**Note**: This method generates new suggestions each time it's called. To retrieve existing suggestions without generating new ones, use Get AI Social Media Posts Suggestions.
 * @public
 * @permissionId REFERRALS.MANAGE_PROGRAM
 * @applicableIdentity APP
 * @fqn wix.loyalty.referral.program.v1.ReferralPrograms.GenerateAISocialMediaPostsSuggestions
 */
declare function generateAiSocialMediaPostsSuggestions(options?: GenerateAiSocialMediaPostsSuggestionsOptions): Promise<NonNullablePaths<GenerateAISocialMediaPostsSuggestionsResponse, `suggestions` | `suggestions.${number}.postContent`>>;
interface GenerateAiSocialMediaPostsSuggestionsOptions {
    /**
     * Topic to generate social media post suggestions for. For example, fitness, education, or technology.
     * @maxLength 512
     */
    topic?: string;
}
/**
 * Retrieves information about the enabled premium features for the referral program.
 * @public
 * @permissionId REFERRALS.READ_PROGRAM
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.loyalty.referral.program.v1.ReferralPrograms.GetReferralProgramPremiumFeatures
 */
declare function getReferralProgramPremiumFeatures(): Promise<NonNullablePaths<GetReferralProgramPremiumFeaturesResponse, `referralProgram`>>;

export { type AISocialMediaPostSuggestion, Action, type ActionEvent, type ActionWithLiterals, type ActivateReferralProgramRequest, type ActivateReferralProgramResponse, App, type AppWithLiterals, type Asset, type BaseEventMetadata, type BillingReference, type BulkGetReferralProgramRequest, type BulkGetReferralProgramResponse, type CancellationDetails, ContractSwitchReason, type ContractSwitchReasonWithLiterals, ContractSwitchType, type ContractSwitchTypeWithLiterals, type ContractSwitched, type Coupon, type CouponDiscountTypeOptionsOneOf, type CouponScope, type CouponScopeOrMinSubtotalOneOf, type Cycle, type CycleCycleSelectorOneOf, type DeleteContext, DeleteStatus, type DeleteStatusWithLiterals, DiscountType, type DiscountTypeWithLiterals, type DomainEvent, type DomainEventBodyOneOf, type Emails, type Empty, type EntityCreatedEvent, type EntityDeletedEvent, type EntityUpdatedEvent, type EventMetadata, type FixedAmountDiscount, type GenerateAISocialMediaPostsSuggestionsRequest, type GenerateAISocialMediaPostsSuggestionsResponse, type GenerateAiSocialMediaPostsSuggestionsOptions, type GetAISocialMediaPostsSuggestionsRequest, type GetAISocialMediaPostsSuggestionsResponse, type GetAiSocialMediaPostsSuggestionsOptions, type GetReferralProgramPremiumFeaturesRequest, type GetReferralProgramPremiumFeaturesResponse, type GetReferralProgramRequest, type GetReferralProgramResponse, type Group, type HtmlSitePublished, type IdentificationData, type IdentificationDataIdOneOf, Initiator, type InitiatorWithLiterals, type Interval, IntervalUnit, type IntervalUnitWithLiterals, type LoyaltyPoints, type MessageEnvelope, type MetaSiteSpecialEvent, type MetaSiteSpecialEventPayloadOneOf, Namespace, type NamespaceChanged, type NamespaceWithLiterals, type OdeditorAssigned, type OdeditorUnassigned, type OneTime, type Page, type PauseReferralProgramRequest, type PauseReferralProgramResponse, type PercentageDiscount, type PicassoAssigned, type PicassoUnassigned, type PremiumFeatures, PriceIncreaseTrigger, type PriceIncreaseTriggerWithLiterals, ProductAdjustment, type ProductAdjustmentWithLiterals, type ProductPriceIncreaseData, type ProgramInSite, ProgramStatus, type ProgramStatusWithLiterals, type ProgramUpdatedEnvelope, ProviderName, type ProviderNameWithLiterals, type ReactivationData, ReactivationReasonEnum, type ReactivationReasonEnumWithLiterals, type RecurringChargeAttemptFailed, type RecurringChargeSucceeded, type ReferralProgram, type RestoreInfo, type Reward, type RewardOptionsOneOf, type ServiceProvisioned, type ServiceRemoved, type SiteCreated, SiteCreatedContext, type SiteCreatedContextWithLiterals, type SiteDeleted, type SiteHardDeleted, type SiteMarkedAsTemplate, type SiteMarkedAsWixSite, type SitePublished, type SitePurgedExternally, type SiteRenamed, type SiteTransferred, type SiteUndeleted, type SiteUnpublished, type SiteUrlChanged, State, type StateWithLiterals, type StudioAssigned, type StudioUnassigned, type Subscription, type SubscriptionAssigned, type SubscriptionAutoRenewTurnedOff, type SubscriptionAutoRenewTurnedOn, type SubscriptionCancelled, type SubscriptionCreated, type SubscriptionEvent, type SubscriptionEventEventOneOf, type SubscriptionNearEndOfPeriod, type SubscriptionPendingChange, SubscriptionStatus, type SubscriptionStatusWithLiterals, type SubscriptionTransferred, type SubscriptionUnassigned, Type, type TypeWithLiterals, UnassignReason, type UnassignReasonWithLiterals, type UpdateReferralProgramRequest, type UpdateReferralProgramResponse, WebhookIdentityType, type WebhookIdentityTypeWithLiterals, activateReferralProgram, bulkGetReferralProgram, generateAiSocialMediaPostsSuggestions, getAiSocialMediaPostsSuggestions, getReferralProgram, getReferralProgramPremiumFeatures, onProgramUpdated, pauseReferralProgram, updateReferralProgram };
